@@ -11,3 +11,7 @@ def is_content_tracing_enabled() -> bool:
 
 def is_metrics_enabled() -> bool:
     return (os.getenv("TRACELOOP_METRICS_ENABLED") or "true").lower() == "true"
+
+
+def is_logging_enabled() -> bool:
+    return (os.getenv("TRACELOOP_LOGGING_ENABLED") or "false").lower() == "true"
